@@ -2,35 +2,39 @@ import base64
 import copy
 import os
 from unittest import TestCase
-import ovf2VmParams
-import ovfenvelope
+from . import ovf2VmParams
+from . import ovfenvelope
 
 OVF = open(
     os.path.join(
         os.path.dirname(__file__),
         'ovf_test.xml'
-    )
+    ),
+    'r'
 ).read()
 
 OVF_w_max_vcpu = open(
     os.path.join(
         os.path.dirname(__file__),
         'ovf_test_max_vcpu.xml'
-    )
+    ),
+    'r'
 ).read()
 
 OVF_42_UNSAFE = open(
     os.path.join(
         os.path.dirname(__file__),
         'ovf_test_v4.2_unsafe.xml'
-    )
+    ),
+    'r'
 ).read()
 
 OVF_42 = open(
     os.path.join(
         os.path.dirname(__file__),
         'ovf_test_v4.2.xml'
-    )
+    ),
+    'r'
 ).read()
 
 EXPECTED_VM_CONF_DICT = {
@@ -330,7 +334,8 @@ EXPECTED_LIBVIRT_XML = (
     '<devices><input type="tablet" bus="usb"></input>'
     '<channel type="unix"><target type="virtio" name="ovirt-guest-agent.0">'
     '</target><source mode="bind" '
-    'path="/var/lib/libvirt/qemu/channels/eccb9cb6-affd-4806-8200-708370581227'
+    'path="/var/lib/libvirt/qemu/channels/'
+    'eccb9cb6-affd-4806-8200-708370581227'
     '.ovirt-guest-agent.0"></source></channel><channel type="unix">'
     '<target type="virtio" name="org.qemu.guest_agent.0"></target>'
     '<source mode="bind" path="/var/lib/libvirt/qemu/channels/'
@@ -517,7 +522,7 @@ EXPECTED_VM_CONF_DICT_42 = {
     'smp': '12',
     'spiceSecureChannels': 'smain,sdisplay,sinputs,scursor,splayback,srecord,'
                            'ssmartcard,susbredir',
-    "xmlBase64": base64.standard_b64encode(EXPECTED_LIBVIRT_XML),
+    "xmlBase64": base64.standard_b64encode(EXPECTED_LIBVIRT_XML.encode()),
 }
 
 
